from setuptools import setup

import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))
path_to_readme = os.path.join(here, "README.md")

long_description = """# Attrsx

**`attrsx` – A Lightweight, Playful Extension to `attrs`**  

🔧 **What is `attrsx`?**  
`attrsx` is a minimal, lightweight extension of the popular `attrs` library, designed to seamlessly add logging capabilities to your `attrs` classes.  

---

### **✨ What It Does:**  
- 🛠️ **Extends `attrs.define`** – Behaves exactly like `attrs.define`, but with automatic logger initialization.  
- 🎛️ **Built-in Logging Fields** – Adds fields for logger name, level, and format – all customizable per class or instance.  
- 🔍 **Non-Intrusive** – If you don’t need logging, `attrsx` functions just like plain old `attrs`.  

---

### **🎯 Why `attrsx`?**  
- 🚀 You sometimes just want **simple logging** without writing the same boilerplate over and over.  
- 😌 `attrsx` lets you keep things clean – adding just a little "magic" to `attrs`-based classes.  
- 🌱 It’s `attrs`, but with room for playful future extensions.  

---

### **🚧 Features at a Glance:**  
- ✅ **Fully compatible** with `attrs` 22.2.0 and later.  
- 🧩 Supports **all `attrs.define` parameters** – like `slots`, `frozen`, and more.  
- 🔧 Logger defaults to the class name but can be **overridden effortlessly**.  

---

✨ It’s `attrs`, but with just a little... **extra**. 😄

"""

if os.path.exists(path_to_readme):
  with codecs.open(path_to_readme, encoding="utf-8") as fh:
      long_description += fh.read()

setup(
    name="attrsx",
    packages=["attrsx"],
    install_requires=['attrs>=22.2.0'],
    classifiers=['Development Status :: 3 - Alpha', 'Intended Audience :: Developers', 'Intended Audience :: Science/Research', 'Programming Language :: Python :: 3', 'Programming Language :: Python :: 3.9', 'Programming Language :: Python :: 3.10', 'Programming Language :: Python :: 3.11', 'Programming Language :: Python :: 3.12', 'License :: OSI Approved :: MIT License', 'Topic :: Scientific/Engineering'],
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="Kyrylo Mordan",
    author_email="parachute.repo@gmail.com",
    description="A lightweight extension of attrs that adds extras like logging.",
    license="mit",
    url="https://kiril-mordan.github.io/reusables/attrsx/",
    keywords=['aa-paa-tool'],
    version="0.0.1",    include_package_data = True,
    package_data = {'attrsx': ['mkdocs/**/*', '.paa.tracking/version_logs.csv', '.paa.tracking/release_notes.md', '.paa.tracking/lsts_package_versions.yml', '.paa.tracking/notebook.ipynb', '.paa.tracking/package_mapping.json', '.paa.tracking/package_licenses.json', '.paa.tracking/.paa.config', '.paa.tracking/python_modules/attrsx.py', '.paa.tracking/.paa.version']} ,
    )
